# DOS Attacks

::: agentdojo.attacks.dos_attacks.DoSAttack
    options:
        filters: ["!attack"]
        heading_level: 2

::: agentdojo.attacks.dos_attacks.SwearwordsDoSAttack
    options:
        filters: ["!attack"]
        heading_level: 2

::: agentdojo.attacks.dos_attacks.CaptchaDoSAttack
    options:
        filters: ["!attack"]
        heading_level: 2

::: agentdojo.attacks.dos_attacks.OffensiveEmailDoSAttack
    options:
        filters: ["!attack"]
        heading_level: 2
